﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using System.Collections.ObjectModel;
using Windows.Storage;
using Windows.Storage.Pickers;

namespace 照片面积计算示例
{
    /// <summary>
    /// 可用于自身或导航至 Frame 内部的空白页。
    /// </summary>
    public sealed partial class MainPage : Page
    {
        ObservableCollection<PhotoInfo> photolist = null;
        public MainPage()
        {
            this.InitializeComponent();

            photolist = new ObservableCollection<PhotoInfo>();
            this.lv.ItemsSource = photolist; //绑定
        }

        private async void OnClick(object sender, RoutedEventArgs e)
        {
            // 选择文件
            FileOpenPicker picker = new FileOpenPicker();
            picker.FileTypeFilter.Add(".jpg");
            picker.FileTypeFilter.Add(".jpeg");

            IReadOnlyList<StorageFile> imgfiles = await picker.PickMultipleFilesAsync();
            photolist.Clear();
            foreach (StorageFile f in imgfiles)
            {
                try
                {
                    PhotoInfo info = new PhotoInfo();
                    // 处理数据
                    await info.ProcessFileAsync(f);
                    // 添加到集合中
                    photolist.Add(info);
                }
                catch(Exception ex)
                {
                    System.Diagnostics.Debug.WriteLine(ex.Message);
                }
            }

            // 对面积进行合计
            double areaTotal = photolist.Sum(p =>
             {
                 // 如果单张照片的面积无效，则返回0
                 if (double.IsInfinity(p.Area))
                 {
                     return 0d;
                 }
                 return p.Area;
             });

            // 显示
            tbTotal.Text = $"共扫描了 {photolist.Count} 张照片，总面积为 {areaTotal.ToString("F2")} 平方厘米。";
        }
    }
}
