﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using Windows.Storage;
using Windows.Storage.Streams;
using Windows.Graphics.Imaging;

namespace 照片面积计算示例
{
    public sealed class PhotoInfo : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged([CallerMemberName]string prop = "")
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(prop));
        }


        #region 私有字段
        // 宽、高，单位像素
        uint m_width = default(uint), m_height = default(uint);
        // 分辨率
        double m_dpix = default(double), m_dpiy = default(double);
        // 面积，单位为平方厘米
        double m_area = default(double);
        // 文件名
        string m_filename = null;
        #endregion

        #region    公共属性
        /// <summary>
        /// 照片宽度
        /// </summary>
        public uint Width
        {
            get { return m_width; }
            private set
            {
                if (m_width != value)
                {
                    m_width = value;
                    OnPropertyChanged();
                }
            }
        }

        /// <summary>
        /// 照片高度
        /// </summary>
        public uint Height
        {
            get { return m_height; }
            private set
            {
                if (value != m_height)
                {
                    m_height = value;
                    OnPropertyChanged();
                }
            }
        }

        /// <summary>
        /// 水平分辨率
        /// </summary>
        public double DpiX
        {
            get { return m_dpix; }
            private set
            {
                if (value != m_dpix)
                {
                    m_dpix = value;
                    OnPropertyChanged();
                }
            }
        }

        /// <summary>
        /// 垂直分辨率
        /// </summary>
        public double DpiY
        {
            get { return m_dpiy; }
            private set
            {
                if (m_dpiy != value)
                {
                    m_dpiy = value;
                    OnPropertyChanged();
                }
            }
        }

        /// <summary>
        /// 面积，平方厘米
        /// </summary>
        public double Area
        {
            get { return m_area; }
            private set
            {
                if (m_area != value)
                {
                    m_area = value;
                    OnPropertyChanged();
                }
            }
        }

        /// <summary>
        /// 文件名
        /// </summary>
        public string FileName
        {
            get { return m_filename; }
            private set
            {
                if (m_filename != value)
                {
                    m_filename = value;
                    OnPropertyChanged();
                }
            }
        }

        #endregion

        #region 公共方法
        public async Task ProcessFileAsync(StorageFile file)
        {
            FileName = file.Name;
            using (IRandomAccessStream stream = await file.OpenReadAsync())
            {
                // 解码
                BitmapDecoder decoder = await BitmapDecoder.CreateAsync(BitmapDecoder.JpegDecoderId, stream);
                // 读取各个值
                Width = decoder.PixelWidth;
                Height = decoder.PixelHeight;
                DpiX = decoder.DpiX;
                DpiY = decoder.DpiY;
            }
            // 计算面积
            double w = Width / DpiX;  //英寸
            double h = Height / DpiY; //英寸
            // 1 inch = 2.54 cm
            Area = w * 2.54d * h * 2.54d;
        }
        #endregion
    }
}
